==> haskell-mmap-0.5.9-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmap
version: 0.5.9
id: mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO
key: mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO
license: BSD-3-Clause
copyright: 2008-2012, Gracjan Polak
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
author: Gracjan Polak <gracjanpolak@gmail.com>
stability: stable
synopsis: Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.
category: System
abi: caaeec6c17e02ec4d65b4454a8e64ae8
exposed: True
exposed-modules:
    System.IO.MMap
import-dirs: /usr/lib/ghc-8.4.3/site-local/mmap-0.5.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mmap-0.5.9
hs-libraries: HSmmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html: /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmap
version: 0.5.9
id: mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
key: mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
license: BSD-3-Clause
copyright: 2008-2012, Gracjan Polak
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
author: Gracjan Polak <gracjanpolak@gmail.com>
stability: stable
synopsis: Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.
category: System
abi: a44b10f342e86754803ff2f7f5010eb9
exposed: True
exposed-modules:
    System.IO.MMap
import-dirs: /usr/lib/ghc-8.6.1/site-local/mmap-0.5.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/mmap-0.5.9
hs-libraries: HSmmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html: /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
